# Datasets

```{eval-rst}
.. module:: annsel.datasets
```

```{eval-rst}
.. currentmodule:: annsel.datasets
```

## Cell $\times$ Gene Datasets

```{eval-rst}
.. autosummary::
    :toctree: ../generated

    leukemic_bone_marrow_dataset
```
